@@ -1,5 +1,5 @@
 /*
- * $Id: st-browser-tab.c,v 1.67 2004/01/30 16:26:40 jylefort Exp $
+ * $Id: st-browser-tab.c,v 1.67.2.2 2004/02/07 18:45:09 jylefort Exp $
  *
  * Copyright (c) 2003, 2004 Jean-Yves Lefort
  * All rights reserved.
@@ -172,7 +172,6 @@ st_browser_tab_init (STBrowserTab *tab)
   tab->statusbar = NULL;
   tab->statusbar_depth = -1;
 
-  tab->refreshing_mutex = g_mutex_new();
   tab->refreshing = FALSE;
 
   tab->thread = NULL;
@@ -356,14 +355,11 @@ static void
 st_browser_tab_update_blinking (STBrowserTab *tab)
 {
   GSList *l;
-  gboolean refreshing;
 
   g_return_if_fail(ST_IS_BROWSER_TAB(tab));
 
-  refreshing = st_browser_tab_is_refreshing(tab);
-
   SG_LIST_FOREACH(l, tab->labels)
-    st_browser_tab_label_set_blinking(ST_BROWSER_TAB_LABEL(l->data), refreshing);
+    st_browser_tab_label_set_blinking(ST_BROWSER_TAB_LABEL(l->data), tab->refreshing);
 }
 
 void
@@ -393,7 +389,7 @@ st_browser_tab_refresh (STBrowserTab *tab)
    */
   st_browser_window_update_title(ST_BROWSER_WINDOW(tab->window));
 
-  if (st_browser_tab_is_refreshing(tab))
+  if (tab->refreshing)
     {
       st_browser_tab_abort(tab);
       gtk_progress_bar_set_fraction(GTK_PROGRESS_BAR(ST_STATUSBAR(tab->statusbar)->progress_bar), 0);
@@ -479,7 +475,7 @@ st_browser_tab_can_stop (STBrowserTab *tab)
 {
   g_return_val_if_fail(ST_IS_BROWSER_TAB(tab), FALSE);
 
-  return st_browser_tab_is_refreshing(tab);
+  return tab->refreshing;
 }
 
 void
@@ -507,29 +503,13 @@ st_browser_tab_set_refreshing (STBrowserTab *tab, gboolean refreshing)
 {
   g_return_if_fail(ST_IS_BROWSER_TAB(tab));
 
-  g_mutex_lock(tab->refreshing_mutex);
   tab->refreshing = refreshing;
-  g_mutex_unlock(tab->refreshing_mutex);
 
   st_statusbar_set_active(ST_STATUSBAR(tab->statusbar), refreshing);
   st_browser_tab_update_blinking(tab);
   st_browser_window_update_sensitivity(ST_BROWSER_WINDOW(tab->window));
 }
 
-gboolean
-st_browser_tab_is_refreshing (STBrowserTab *tab)
-{
-  gboolean refreshing;
-
-  g_return_val_if_fail(ST_IS_BROWSER_TAB(tab), FALSE);
-
-  g_mutex_lock(tab->refreshing_mutex);
-  refreshing = tab->refreshing;
-  g_mutex_unlock(tab->refreshing_mutex);
-
-  return refreshing;
-}
-
 void
 st_browser_tab_update (STBrowserTab *tab)
 {
@@ -540,18 +520,19 @@ st_browser_tab_update (STBrowserTab *tab)
   g_return_if_fail(ST_IS_BROWSER_TAB(tab));
 
   g_mutex_lock(tab->handler->mutex);
-
   is_bookmarks = ST_CATEGORY_IS_BOOKMARKS(tab->handler->selected_category);
   found = st_handler_streams_get(tab->handler, tab->handler->selected_category->name, &streams);
+  g_mutex_unlock(tab->handler->mutex);
 
   if (is_bookmarks || found)
     {
-      if (st_browser_tab_is_refreshing(tab))
+      if (tab->refreshing)
 	{
 	  st_browser_tab_abort(tab);
 	  st_browser_tab_set_refreshing(tab, FALSE);
 	}
 	  
+      g_mutex_lock(tab->handler->mutex);
       st_browser_tab_set_contents(tab,
 				  tab->handler->selected_category,
 				  tab->handler->stock_categories,
@@ -559,10 +540,9 @@ st_browser_tab_update (STBrowserTab *tab)
 				  streams,
 				  sgtk_tree_view_is_empty(GTK_TREE_VIEW(tab->category_view)),
 				  TRUE);
+      g_mutex_unlock(tab->handler->mutex);
     }
 
-  g_mutex_unlock(tab->handler->mutex);
-
   if ((! is_bookmarks) && ((! found) || st_settings.always_refresh))
     st_browser_tab_refresh(tab);
 }
