@@ -1,5 +1,5 @@
 /*
- * $Id: st-transfer.c,v 1.46 2004/01/28 17:16:41 jylefort Exp $
+ * $Id: st-transfer.c,v 1.46.2.1 2004/02/07 19:22:54 jylefort Exp $
  *
  * Copyright (c) 2002, 2003, 2004 Jean-Yves Lefort
  * All rights reserved.
@@ -648,13 +648,13 @@ st_transfer_session_get_by_line_cb (char *buffer,
 {
   STTransferLineData *line_data = data;
   size_t len;
-  int start;
-  int i;
+  int start = 0;
+  int i = 0;
 
   len = size * nitems;
 
   /* handle lf (UNIX), crlf (DOS) and cr (Mac) */
-  for (start = i = 0; i < len; i++)
+  while (i < len)
     if (buffer[i] == '\n' || buffer[i] == '\r')
       {
 	int newline_len;
@@ -664,15 +664,16 @@ st_transfer_session_get_by_line_cb (char *buffer,
 	  : 1;			/* cr or lf */
 
 	g_string_append_len(line_data->line, &buffer[start], i - start);
-
 	if (line_data->transfer->flags & ST_TRANSFER_PASS_NEWLINE)
 	  g_string_append_len(line_data->line, &buffer[i], newline_len);
 
 	line_data->line_cb(line_data->line->str, line_data->line_cb_data);
 	g_string_truncate(line_data->line, 0);
 
-	start = i + newline_len;
+	start = i += newline_len;
       }
+    else
+      i++;
   
   if (start < len)
     g_string_append_len(line_data->line, &buffer[start], len - start);
